import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';
import { BackgroundCircle } from './BackgroundCircle';
import { Eyes } from './Eyes';
import { Mouth } from './Mouth';

const strokeWidth = 20;
const eyeOffsetX = 90;
const eyeOffsetY = 100;
const eyeRadius = 40;
const mouthWidth = 20;
const mouthRadius = 140;

export const FaceContainer = ({children, width, height}) => {
  const centerX = width / 2
  const centerY = height / 2
  
  return(
    <svg width={width} height={height}>
      <g transform={`translate(${centerX},${centerY})`}>
        {children}
      </g>
  	</svg>
  )
}

const App = () => (
    <FaceContainer      
      width = {960} 
      height = {500}>
  		<BackgroundCircle 
        radius={centerY - strokeWidth / 2} 
        strokeWidth= {strokeWidth} />
      <Eyes 
        eyeOffsetX={eyeOffsetX} 
        eyeOffsetY={eyeOffsetY} 
        eyeRadius={eyeRadius}/>
      <Mouth 
        mouthRadius={mouthRadius} 
        mouthWidth={mouthWidth}/>
    </FaceContainer>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);